==> smalltalk-1.6.2.tar.gz: smalltalk-1.6.2/acconfig.h <==
/* acconfig.h
   Copyright 1990, 91, 92, 94, 95, 99 Free Software Foundation, Inc.
   Written by Steve Byrne.

   $Revision$ $Date$

   Descriptive text for the C preprocessor macros that
   the distributed Autoconf macros can define.
   No software package will use all of them; autoheader copies the ones
   your configure.in uses into your configuration header file templates.

   The entries are in sort -df order: alphabetical, case insensitive,
   ignoring punctuation (such as underscores).  Although this order
   can split up related entries, it makes it easier to check whether
   a given entry is in the file.

   Leave the following blank line there!!  Autoheader needs it.  */


/* Define as __const if that's what the C compiler calls it.  */
#undef const

/* Define this with the memory alignment required by type "double" */
#define DOUBLE_ALIGNMENT 0

/* Enabling this makes the the allocator run the GC with each allocation to
 * test for non-incubated objects being freed too soon.
 */
#undef GC_TORTURE

/* Define if your system's dynamic loading method is supported.  */
#undef HAVE_DLD

/* Define if your CC has the `&&' and `goto void *' GCC extensions. */
#undef HAVE_GOTO_VOID_P

/* Define if your system's sockets provide access to the Internet.  */
#undef HAVE_INET_SOCKETS

/* Define as __inline if that's what the C compiler calls it.  */
#undef inline

/* Define if you have unistd.h and it defines ioctl (like IRIX 5.3's does) */
#undef IOCTL_IN_UNISTD_H

/* Define if your system's localtime(3) caches the timezone.  */
#undef LOCALTIME_CACHE

/* The set of builtin preprocessor symbols which are defined in the current 
 * environment.
 */
#define MACHINE_DEFINES "unknown", 

/* Define if your system is a loser one with 8.3 filenames  */
#undef NAMES83

/* Define if your system lacks the getpriority and setpriority system calls,
   but has `nice' instead.  */
#undef NICE_PRIORITY

/* Define if the C compiler doesn't support void * and enums.  */
#undef OLDCC

/* Define as empty if the C compiler doesn't support it.  */
#undef signed

/* Major version of GNU Smalltalk */
#define ST_MAJOR_VERSION 0

/* Minor version of GNU Smalltalk */
#define ST_MINOR_VERSION 0

/* Patch level version of GNU Smalltalk */
#define ST_EDIT_VERSION 0

/* Prefix (like "alpha" or "test" before the edit number) */
#define ST_EDIT_PREFIX ""

/* This is anbled if you wnat the also ultra-winning GNU readline library
 * to be present in the command reader.
 */
#undef HAVE_READLINE

/* The current version of GNU Smalltalk */
#define VERSION 0.0

/* **********************************************************************
 * **********************************************************************
 * 
 * These definitions hack around a bug with the GNU autoconf package.
 * autoheader will complain that these symbols are not defined in acconfig.h
 * if they are not present here.  But, other higher level AC_ macros in
 * configure.in will cause them to be emitted anyway, so now they go out
 * twice in gstconf.h.  
 * 
 * **********************************************************************
 * ********************************************************************** */

#undef HAVE_SYS_TIME_H

#undef HAVE_GETTIMEOFDAY


/* Leave that blank line there!!  Autoheader needs it.
   If you're adding to this file, keep in mind:
   The entries are in sort -df order: alphabetical, case insensitive,
   ignoring punctuation (such as underscores).  */

==> smalltalk-1.8.5.tar.gz: smalltalk-1.8.5/acconfig.h <==
/* acconfig.h
   Copyright 1988-92, 1994-95, 1999, 2000 Free Software Foundation, Inc.
   Written by Steve Byrne.

   $Revision: 1.8.5$
   $Date: 2000/12/27 10:45:49$

   Descriptive text for the C preprocessor macros that
   the distributed Autoconf macros can define.
   No software package will use all of them; autoheader copies the ones
   your configure.in uses into your configuration header file templates.

   The entries are in sort -df order: alphabetical, case insensitive,
   ignoring punctuation (such as underscores).  Although this order
   can split up related entries, it makes it easier to check whether
   a given entry is in the file.

   Leave the following blank line there!!  Autoheader needs it.  */


/* Define as __const if that's what the C compiler calls it.  */
#undef const

/* Define this with the memory alignment required by type "double" */
#define DOUBLE_ALIGNMENT 0

/* Define if your system's dynamic loading method is supported.  */
#undef HAVE_DLD

/* Define if your CC has the `&&' and `goto void *' GCC extensions. */
#undef HAVE_GOTO_VOID_P

/* Define if your system's sockets provide access to the Internet.  */
#undef HAVE_INET_SOCKETS

/* Define if your system has Tcl/Tk, 8.0 or later, installed.  */
#undef HAVE_TCLTK

/* Define to the path in which an image will be looked for */
#undef IMAGE_PATH

/* Define as __inline if that's what the C compiler calls it.  */
#undef inline

/* Define if you have unistd.h and it defines ioctl (like IRIX 5.3's does) */
#undef IOCTL_IN_UNISTD_H

/* Define to the path in which the kernel files will be looked for */
#undef KERNEL_PATH

/* Define if your system's localtime(3) caches the timezone.  */
#undef LOCALTIME_CACHE

/* The set of builtin preprocessor symbols which are defined in the current 
 * environment. */
#define MACHINE_DEFINES "unknown", 

/* Define if your system is a loser one with 8.3 filenames  */
#undef NAMES83

/* Define if your system's dynamic loading method needs a _ to be
 * prepended to the function name.  */
#undef NEED_DLSYM_UNDERSCORE

/* Define if the C compiler doesn't support void * and enums.  */
#undef OLDCC

/* Define if your system does not support va_arg(..., char)  */
#undef PICKY_VA_ARG

/* Define as empty if the C compiler doesn't support it.  */
#undef signed

/* Major version of GNU Smalltalk */
#define ST_MAJOR_VERSION 0

/* Minor version of GNU Smalltalk */
#define ST_MINOR_VERSION 0

/* Patch level version of GNU Smalltalk */
#define ST_EDIT_VERSION 0

/* This is anbled if you wnat the also ultra-winning GNU readline library
 * to be present in the command reader. */
#undef HAVE_READLINE

/* Whether to enable the dynamic translator to threaded code -- it does not
 * work for all machines, and it suppresses a few command line options,
 * so you must enable it explicitly. */
#define USE_DYNAMIC_TRANSLATION

/* The current version of GNU Smalltalk */
#define VERSION "0.0"

/* **********************************************************************
 * **********************************************************************
 * 
 * These definitions hack around a bug with the GNU autoconf package.
 * autoheader will complain that these symbols are not defined in acconfig.h
 * if they are not present here.  But, other higher level AC_ macros in
 * configure.in will cause them to be emitted anyway, so now they go out
 * twice in gstconf.h.  
 * 
 * **********************************************************************
 * ********************************************************************** */

#undef HAVE_SYS_TIME_H

#undef HAVE_GETTIMEOFDAY


/* Leave that blank line there!!  Autoheader needs it.
   If you're adding to this file, keep in mind:
   The entries are in sort -df order: alphabetical, case insensitive,
   ignoring punctuation (such as underscores).  */
